@@ -62,6 +62,8 @@ perform.svm = function(training.set,
   
   
   classes = c(classes.training.set, classes.test.set)
+  # converting strings to factors
+  classes = factor(classes)
   input.data = as.data.frame(rbind(training.set,test.set))
   input.data = cbind(classes, input.data)
   training.classes = c(1:length(training.set[,1]))
